package GestaoBancos;

/**
 * Nota: para compilar no BlueJ, activar a opo "Enable JDK 1.4 features(assertions)"
 * em Tools -> Preferences ...
 * Para compilar com "javac"  necessrio indicar a opo "javac -source 1.4".
 */

/**
 * Contm classe TesteContas.
 * 
 * @author (Joo Carlos Pascoal Faria) 
 * @version (30 de Janeiro de 2003)
 */
public class TesteContas
{

    /**
     * Efectua divirsos testes das classes Cliente e ContaBancaria.
     * Se chegar ao fim com a mensagem "Teste bem sucedido!", tudo correu bem.
     * Utiliza a instruo "assert <condio>;" para efectuar os testes.
     * Se falhar algum teste, o programa termina com uma excepo.
     * */
    public static void main(String args[]) throws ContaBancaria.ContaBancariaException
    {
        // Cria um cliente individual
        ClienteIndividual cliente1 = new ClienteIndividual(1, "Joo", 1);
        
        // Verifica se os dados do cliente esto correctos
        // Nota: d AssertionError e aborta programa se condio no se verificar
        assert cliente1.getNome() == "Joo";
        assert cliente1.getNumero() == 1;
         
        // Imprime os dados do cliente
        System.out.println(cliente1);
        
         // Cria um cliente empresarial e imprime os dados
        Cliente cliente2 = new ClienteEmpresarial(2, "JMB S.A.", cliente1);
        System.out.println(cliente2);
        
        // Cria uma conta poupanca com saldo 0 e imprime os dados
        ContaBancaria conta1 = new ContaBancaria(cliente1);
        System.out.println(conta1);
        
        // Verifica se os dados da conta esto correctos
        assert conta1.getNumero() == 1;
        assert conta1.getCliente() == cliente1;
        assert conta1.getSaldo() == 0.0;
        
        // Cria outra conta
        ContaPoupanca conta2 = new ContaPoupanca(cliente2, 2000.0, 5.0);
        System.out.println(conta2);
        
        // Verifica se os dados da conta esto correctos
        assert conta2.getNumero() == 2;
        assert conta2.getCliente() == cliente2;
        assert conta2.getSaldo() == 2000.0;
        
        // Deposita valor na primeira conta
        conta1.depositar(1000.0);
        
        // Verifica se o saldo ficou correcto
        assert conta1.getSaldo() == 1000.0;
        
        // Retira valor da primeira conta
        // (No deve dar SaldoInsuficiente; se der aborta programa)
        conta1.levantar(1000.0);
        
        // Verifica se o saldo ficou correcto
        assert conta1.getSaldo() == 0.0;
        
        // Tenta retirar com saldo insuficiente
        // (deve dar excepo)
        boolean deuSaldoInsuficiente = false;
        try
        {
            conta1.levantar(1000.0);
        }
        
        // Apanha excepo
        catch(ContaBancaria.SaldoInsuficiente e)
        {
            deuSaldoInsuficiente = true;
        }
        
        // Verifica se deu excepo e manteve saldo anterior como esperado
        assert conta1.getSaldo() == 0.0 && deuSaldoInsuficiente; 
               
        // Transfere valor entre contas
        // (No deve dar SaldoInsuficiente; se der aborta programa)
        ContaBancaria.transferir(1000.0, conta2, conta1);        
        
        // Verifica se os saldos ficaram correctos
        assert conta1.getSaldo() == 1000.0 && conta2.getSaldo() == 1000.0; 
  
        // Acumula juros
        System.out.println("Antes de acumular juros:");
        System.out.println(conta2);
        conta2.acumulaJuros();
        System.out.println("Depois de acumular juros:");
        System.out.println(conta2);
        
        // Se chegou aqui e no deu nenhuma abortou com uma excepo ou erro, tudo bem
        System.out.println("Teste bem sucedido!");
    }  
}
