
/**
 * Programa que gera N apostas aleatrias do totoloto.
 * 
 * @author Joo Carlos Pascoal Faria
 * @version 23 de Janeiro de 2003
 */

import java.io.*;  // usado por mtodo inputInt

public class totoloto
{

   /***** Mtodos Auxiliares para Trabalhar com Arrays ********/
    
   // sort elements of array with bubble sort (Deitel & Deitel, Java How to Program)
   public static void sort( int array[] )
   {   
      // loop to control number of passes
      for ( int pass = 1; pass < array.length; pass++ ) 
      { 
         // loop to control number of comparisons
         for ( int i = 0; i < array.length - 1; i++ ) 
         {
            // compare side-by-side elements and swap them if 
            // first element is greater than second element
            if ( array[ i ] > array[ i + 1 ] )
               swap( array, i, i + 1 );
         }
      }  
   }

   // swap two elements of an array
   public static void swap( int array[], int first, int second )
   {
      int hold = array[ first ];         
      array[ first ] = array[ second ];  
      array[ second ] = hold;
   }

    // Verifica se dois arrays so iguais
    public static boolean equal(int a[], int b[])
    {
        if (a.length != b.length)
            return false;
            
        for (int i = 0; i < a.length; i++)
            if (a[i] != b[i])
                return false;
                
        return true;
    }
    
    
    // Searches a "key" in a "array", between positions "low" and "high"
    // Returns the position where it was found or -1, in case it is not found
    public static int sequentialSearch( int array[], int low, int high, int key)                 
    {             
        for (int i = low; i <= high; i++)
            if (array[i] == key)
                return i;  // key found at position "i"
                
        return -1; // key not found
    }
    
    // Searches an "array" in an "array of arrays", between positions "low" and "high"
    // Returns the position where it was found, or -1 in case it is not found
    public static int sequentialSearch( int arrayOfArrays[][], int low, int high, int array[])                 
    {             
        for (int i = low; i <= high; i++)
            if (equal(arrayOfArrays[i], array) )
                return i;  // found at position "i"
                
        return -1; // not found
    }

   /***** Trabalhar com Apostas do Totoloto ********/

    static final int TAMANHO_APOSTA = 6;
    static final int MAXIMO_APOSTA = 47;

    // Imprime um array com aposta do totoloto no ecr, precedida de um ttulo 
    static void imprimeAposta(String titulo, int aposta[])
    {
         System.out.print(titulo);   
         
         for (int i = 0; i < aposta.length; i++)
            System.out.print(" " + aposta[i]); 
            
         System.out.println("");
    }

    // Preenche array com aposta de totoloto gerada aleatoriamente,
    // isto , com valores distintos compreendidos entre 1 e MAXIMO_APOSTA.
    // Os valores ficam ordenados.
    static void geraAposta(int aposta[])
    {
        // ciclo para percorrer e preencher as vrias posies do array
        for (int i = 0; i < aposta.length; i++)
        {
            int proximoValor;
            
            // gera valor at ser diferente dos anteriores
            do
                proximoValor =  1 + (int)(Math.random() * MAXIMO_APOSTA);
            while (sequentialSearch(aposta, 0, i, proximoValor) != -1);

            // guarda valor no array                
            aposta[i] = proximoValor;
        }
        
        // ordena a aposta
        sort(aposta);
     }
        
    
    // Imprime no ecr "n" apostas do totoloto diferentes geradas aleatoriamente, 
    // com "n" dado pelo utilizador
    public static void main(String args[])
    {   
        // Le do utilizador o nmero "n" de apostas
        int n = inputInt("Introduza o numero de apostas: ");
        
        // Cria um array de arrays para guardar todas as apostas que vo ser geradas
        int apostas[][] = new int[n][TAMANHO_APOSTA];
        
        // Ciclo para gerar e imprimir as "n" apostas diferentes
        for (int i = 0; i < n; i++)
        {            
            // tenta gerar uma aposta at ser diferente das anteriores
            do
                geraAposta(apostas[i]);
            while(sequentialSearch(apostas, 0, i-1, apostas[i]) != -1);
            
            // imprime agora esta aposta bo ecr
            imprimeAposta("Aposta " + (i+1) + ":", apostas[i]);
        }       
    }
    
    
    /*********** Trabalhar Com Standard Input ****************/
    
    // Mtodo auxiliar para ler um inteiro do "standard input" em resposta a uma pergunta
    public static int inputInt(String prompt)
    {       
        // Tenta ler
        try
        {
            // Escreve a pergunta no ecr
            System.out.print(prompt);
            
            // Preparar um objecto para leitura do "standard input" (teclado) 
            BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
            
            // L uma linha de texto do "standard input"
            String input = in.readLine();
            
            // COnverte para inteiro e retorna esse valor 
            return Integer.parseInt(input);
        }
        
        // Em caso de erro devolve 0
        catch(Exception e ) 
        { 
            return 0;
        }
     }
}
